<template>
    <el-dialog
        :visible.sync="dialogVisible" class="position-absolute dialog-center dialog-no-header" width="840px"
        top="0" :modal="false" :destroy-on-close="true" :close-on-press-escape="false" :close-on-click-modal="false"
        :modal-append-to-body="false"
        v-loading="loading" element-loading-text="拼命加载中"
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(0, 0, 0, 0)">
        <mw-step v-model="step"></mw-step>
        <div class="step-list">
            <div class="step-item" v-show="step == 0">
                <new-test @nextStep="newTest"></new-test>
            </div>
            <div class="step-item" v-show="step == 1" v-if="step>0">
                <test-data-input :type="params.type" @nextStep="dataInput"></test-data-input>
            </div>
            <div class="step-item" v-show="step == 2" v-if="step>1">
                <test-step-confirm v-if="type=='fz'" @nextStep="completeTest"></test-step-confirm>
                <test-step-confirm-kz v-else-if="type=='kz'" @nextStep="completeTest"></test-step-confirm-kz>
            </div>
        </div>
    </el-dialog>
</template>

<script>
import mwStep from "@/components/smallModule/mwStep";
import newTest from "@/pages/test/dialog/newTest";
import TestDataInput from "@/pages/test/dialog/testDataInput";
import TestStepConfirm from "@/pages/test/dialog/testStepConfirm";
import testStepConfirmKz from "@/pages/test/dialog/testStepConfirmKz";
import {addKzFzTest} from "@/pages/test/js/api";

export default {
    name: "LoadTestDialog",
    props: {
        visible: {
            type: Boolean,
            default: false,
        },
        type: {
            require: true,
            type: String,
        }
    },
    components: {
        TestStepConfirm,
        TestDataInput,
        mwStep,
        newTest,
        testStepConfirmKz
    },
    data() {
        return {
            loading: false,
            step: 0,
            dialogVisible: false,
            params: {
                baseData: {
                    experimentId: "",           // 试验编号
                    gearSpeedRatio: "",         // 齿轮转速比
                    ratedLateralSpeed: 0,       // 高速侧转速,单位:r/min
                    ratedPower: 0,              // 额定功率,单位KW
                    ratedRotateSpeed: 0,        // 额定转速,单位:r/min
                    ratedVol: 0                 // 额定电压,单位V
                },
                createTime: "",         // 创建时间
                deviceId: "",           // 被测设备id
                deviceSn: "",           // 被测设备SN
                duration: "",           // 试验时长
                endTime: "",            // 结束时间
                id: "",                 // 试验编号
                name: "",               // 试验名称
                point: [],
                projectId: 0,           // 对应的项目
                rz_link: 0,             // 各相绕组连接情况 0 引出; 1 内部连接
                startTime: "",          // 启动时间
                status: 0,              // 状态:-1-取消,0-未开始,1-进行中,2-完成
                type: "",               // 试验类型:九大试验
                userId: 0,              // 负责人
                username: ""            // 负责人姓名
            }
        }
    },
    watch: {
        visible(value) {
            this.dialogVisible = value;
        },
    },
    methods: {
        newTest(data) {
            this.params.name = data.name;
            this.params.projectId = data.projectId;
            this.step++;
        },
        dataInput(data) {
            this.params.baseData.experimentId = data.experimentId;
            this.params.id = data.experimentId;
            this.params.deviceSn = data.deviceSn;
            this.params.deviceId = data.deviceId;
            this.params.baseData.ratedPower = data.ratedPower;
            this.params.baseData.ratedVol = data.ratedVol;
            this.params.baseData.gearSpeedRatio = data.gearSpeedRatio;
            this.params.baseData.ratedRotateSpeed = data.ratedRotateSpeed;
            this.params.baseData.ratedLateralSpeed = data.ratedLateralSpeed;
            this.step++;
        },
        completeTest(data) {
            let experimentId = this.params.baseData.experimentId;
            this.params.point = data.point.map(item => {
                item.experimentId = experimentId;
                return item;
            });
            this.loading = true;
            addKzFzTest(this.params).then(res => {
                let rs = res.data;
                console.log(rs);
                if (rs.code == 1) {
                    this.dialogVisible = false;
                    this.$nextTick(() => {
                        this.$layer.msg("生成试验成功");
                    });
                } else {
                    this.$layer.msg("生成试验失败");
                }
                this.loading = false;
            }).catch(error => {
                this.$layer.msg("请检测网络");
                this.loading = false;
            });
        },
    },
    mounted() {
        this.params.type = this.type;
        this.dialogVisible = this.visible;
    }
}
</script>

<style scoped>

</style>